# Esercizio Project management
#  DATI
set Activities;
set Precedences within Activities cross Activities;
param dA {Activities};		# Durata con 100% di A
param dB {Activities};		# Durata con 100% di B
param eta := 0.52;				# Frazione di A nella miscela
param M := 200;

# VARIABILI
var s {Activities} >=0;			# Inizio attivit [min]
var e {Activities};				# Fine attivit [min]
var Makespan;					# Durata totale [min]
var x {Activities,Activities} binary;   # Var=1 se i inizia prima che j sia finita. Se x(i,j)=x(j,i)=1, allora i e j sono attive simultaneamente

# VINCOLI
# Vincoli di precedenza [min]
subject to Precedenze {(i,j) in Precedences}:
  s[j] >= e[i];

# Vincolo sulla durata di ogni attivit [min]
subject to InizioFine {i in Activities}:
  e[i] - s[i] >= eta * dA[i] + (1 - eta) * dB[i];

# Linearizzazione f.o. min-max [min]
subject to DurataTotale {i in Activities}:
  Makespan >= e[i];

# Relazione tra  varaibili x e  variabili s(i) e e(i)
subject to Relaz_x_s_e {i in Activities, j in Activities}:
  e[j] - s[i] <= x[i,j] * M; 

# Max numero operatori = 2
#subject to Solo2 {i in Activities, j in Activities, k in  Activities: (i<>j) and (j<>k) and (i<>k)}:
#  x[i,j] + x[j,i] + x[j,k] + x[k,j] + x[i,k] + x[k,i] <= 5; 

# Max numero operatori = 1
subject to Solo1 {i in Activities, j in Activities: (i<>j)}:
  x[i,j] + x[j,i] <= 1; 

# OBIETTIVO
# Minimizzare la durata totale del progetto [min]
minimize z: Makespan;

###################
data;
set Activities := A B C D E F G H;

set Precedences :=
A D
B E
B F
C F
D G
D H
E G
E H;

param:	dA		dB :=
A		30		20
B		15		45
C		25		 5
D		32		12
E		14		12
F		19		49
G		20		10
H		10		18;

end;
